#!/bin/bash
#####################################################################
# This script parses netperfmeter's (modified) stdout output into
# a form that can be plotted by GnuPlot. The script searches the
# current directory for *rx.txt files. It parses each of them for
# Rx bandwidth stats and CPU load stats, and put the collected data
# into *.dat files in the current working directory. The data can
# then be plotted with GnuPlot scripts: mptcp_plot.gp and sctp_plot.gp.
#####################################################################

for input in *.txt
do

		bw_dat=${input%.*}.bw.dat
		cpu_dat=${input%.*}.cpu.dat

# Sample lines from input file. Columns are delimited by the space char.
# 0:00:01 N: 0 Tx: 0.00 MiB 0.0 Kbps Rx: 0.00 MiB 0.0 Kbps CPU% 0.0 / 0.0 [ 0.0 ]
# 0:00:02 N: 0 Tx: 0.00 MiB 0.0 Kbps Rx: 0.00 MiB 0.0 Kbps CPU% 0.0 / 0.0 [ 0.0 ]
# 0:00:03 N: 0 Tx: 0.00 MiB 0.0 Kbps Rx: 0.00 MiB 0.0 Kbps CPU% 0.0 / 0.0 [ 0.0 ]

		# Column 12: Rx bandwidth in Kbits/sec, converted to Mbits/sec
		# Take average of every 5 data points
		awk 'BEGIN {i = 1; x = 0}; /Rx/ {	\
			if ($12 != 0 && i <= 600) { 	\
				x = x + $12;				\
				if (i % 5 == 0) {			\
					print i,x/5/1000;		\
					x = 0;					\
				}							\
				i++;						\
			}								\
		}' $input > $bw_dat
		echo " *** Created:  ${bw_dat}"
		
		# Column 19: Total CPU utilization (avg of all CPUs)
		# Take average of every 5 data points
		awk 'BEGIN {i = 1; x = 0}; /Rx/ {	\
			if ($19 != 0 && i <= 600) { 	\
				x = x + $19;				\
				if (i % 5 == 0) {			\
					print i,x/5;			\
					x = 0;					\
				}							\
				i++;						\
			}								\
		}' $input > $cpu_dat
		echo " *** Created:  ${cpu_dat}"

done



