#!/bin/bash
#####################################################################
# This script plots the throughput of MPTCP, CMT-SCTP, and
# TCP-FreeBSD data all in one graph. This runs from the results 
# directory, which must have subdirs for each data set 
# (i.e., 3g, 4g, wifi, etc.).
#####################################################################

parser=../../scripts/parse_data.sh
for dir in 3g 4g wifi wired
do
	echo "Parsing results for ${dir}"
	cd $dir && ../${parser} && cd ..
done



function plot {
	type=$1
	dat=$2
	units=$3
	title=$4

gnuplot <<EOT
reset

set xlabel "time (sec)"
set ylabel "$units"
set title "$title"
set key reverse Left outside
set grid
set style data linespoints

plot "$type/mptcp1.$dat.dat" using 1:2 title "MPTCP (1 flow)",\
"$type/sctp1.$dat.dat" using 1:2 title "CMT-SCTP (1 flow)",\
"$type/tcp1-bsd.$dat.dat" using 1:2 title "TCP (1 flow)",\
"$type/tcp2-bsd.$dat.dat" using 1:2 title "TCP (2 flows)",\
"$type/tcp3-bsd.$dat.dat" using 1:2 title "TCP (3 flows)"
EOT
}

plot 4g rx.bw Mbit/sec "Throughput, 4G-LTE (100Mb/100Mb, 30ms, 0%)"
plot 3g rx.bw Mbit/sec "Throughput, 3G-HSPA+ (56Mb/22Mb, 80ms, 0%)"
plot wifi rx.bw Mbit/sec "Throughput, 802.11g (54Mb/54Mb, 2ms, 0%)"
plot wired rx.bw Mbit/sec "Throughput, Ethernet (100Mb/100Mb, 2ms, 0%)"

plot 4g rx.cpu % "CPU Utilization, Rx, 4G-LTE (100Mb/100Mb, 30ms, 0%)"
plot 3g rx.cpu % "CPU Utilization, Rx, 3G-HSPA+ (56Mb/22Mb, 80ms, 0%)"
plot wifi rx.cpu % "CPU Utilization, Rx, 802.11g (54Mb/54Mb, 2ms, 0%)"
plot wired rx.cpu % "CPU Utilization, Rx, Ethernet (100Mb/100Mb, 2ms, 0%)"

plot 4g tx.cpu % "CPU Utilization, Tx, 4G-LTE (100Mb/100Mb, 30ms, 0%)"
plot 3g tx.cpu % "CPU Utilization, Tx, 3G-HSPA+ (56Mb/22Mb, 80ms, 0%)"
plot wifi tx.cpu % "CPU Utilization, Tx, 802.11g (54Mb/54Mb, 2ms, 0%)"
plot wired tx.cpu % "CPU Utilization, Tx, Ethernet (100Mb/100Mb, 2ms, 0%)"

