#!/bin/sh
#####################################################################
# This script creates an output directory, and runs a single
# 120-second MPTCP throughput test with a server host. The test uses
# netperfmeter 1.1.9 on Ubuntu.
#
# See manpage: http://dev.man-online.org/man8/netperfmeter/
#####################################################################

if [ ! $1 ]; then
	echo "error: $0 {flowcount}"
	exit 1
fi

# Only run if MPTCP is on. We can't enable it on the fly with the sysctl cmd.
if ! sysctl -n net.mptcp.mptcp_enabled > /dev/null 2>&1; then
	# key doesn't exist (not Linux MPTCP)...not ok
	echo "error: MPTCP not detected"
	exit 1
fi
if [ $(sysctl -n net.mptcp.mptcp_enabled) -eq 0 ]; then
	echo "error: MPTCP is disabled (sysctl.net.mptcp.mptcp_enabled=0)"
	exit 1
fi

# Install libsctp if not found
if [ ! "$(find /usr/lib -name 'libsctp*')" ]; then
	sudo apt-get -y -q install libsctp1
fi

outdir=results/$(basename ${0%.*})_$(uname -n | awk 'BEGIN { FS = "." } ; {print $2}')
npm=../bin/netperfmeter-ubu64
server=node1:9000

# Duration of throughput tests (in seconds)
runtime=120

# Outgoing rate. Set to 'const0' to send as much as possible.
# Packet size = 1452 (MTU 1500 - IP/UDP header)
outrate=const0
outlen=const1452

# No incoming flow (half-duplex). set both rate and size 
# to 'const0' to disable
inrate=const0
inlen=const0

# Tx buffer should be set as high as allowed by kernel.
# Rx buffer should be half the Tx buffer.
rcvbuf=rcvbuf=7000000
sndbuf=sndbuf=14000000

flowspec=$outrate:$outlen:$inrate:$inlen:$rcvbuf:$sndbuf

# Create output dir if necessary
[ ! -d $outdir ] && mkdir -p $outdir 2>/dev/null

echo "*** Running MPTCP test (flows=$1) for $runtime seconds"
pre=mptcp$1
$npm $server $(yes " -tcp $flowspec" | head -n$1) -runtime=$runtime > ${outdir}/${pre}.tx.txt
