#!/bin/sh
#####################################################################
# This script creates an output directory, and runs a single
# 120-second SCTP throughput test with a server host. The test uses
# netperfmeter 1.1.9 on FreeBSD.
#
# See manpage: http://dev.man-online.org/man8/netperfmeter/
#####################################################################

if [ ! $1 ]; then
	echo "Usage: $0 {numflows}"
	exit 1
fi

# Enable CMT-SCTP for the next benchmarks
sudo sysctl net.inet.sctp.cmt_on_off=1

outdir=results/$(basename ${0%.*})_$(uname -n | awk 'BEGIN { FS = "." } ; {print $2}')
npm=../bin/netperfmeter-bsd64
server=node1:9000

# Duration of throughput tests (in seconds)
runtime=120

# Outgoing rate. Set to 'const0' to send as much as possible.
# Packet size = 1452 bytes (MTU of 1500 - IP/UDP header)
outrate=const0
outlen=const1452

# No incoming flow (half-duplex). set both rate and size 
# to 'const0' to disable
inrate=const0
inlen=const0

# CMT mode
#  normal = Normal (independent paths)
#  cmtrpv1 = Resource pooled (v1)
#  cmtrpv2 = Resource pooled (v2)
#  like-mptcp = Like MPTCP
#  off = primary path (regular SCTP)
cmtmode=cmt=normal

# Tx buffer should be set as high as allowed by kernel.
# Rx buffer should be half the Tx buffer.
rcvbuf=rcvbuf=7000000
sndbuf=sndbuf=14000000

# Set fraction of traffic to be unordered (0 <= x <= 1.0)
# Setting to 1 disables packet ordering, reducing overhead
# and delay.
ord=unordered=1

flowspec=$outrate:$outlen:$inrate:$inlen:$cmtmode:$rcvbuf:$sndbuf:$ord

# Create output directory if necessary
[ ! -d $outdir ] && mkdir -p $outdir 2>/dev/null

echo "*** Running SCTP test (flows=$1) for $runtime seconds"
pre=sctp$1
$npm $server $(yes " -sctp $flowspec" | head -n$1) -runtime=$runtime > ${outdir}/${pre}.tx.txt
