#!/bin/sh
#####################################################################
# This script creates an output directory, and runs a single
# 120-second TCP throughput test with a server host. The test uses
# netperfmeter 1.1.9 on FreeBSD.
#
# See manpage: http://dev.man-online.org/man8/netperfmeter/
#####################################################################

if [ ! $1 ]; then
	echo "Usage: $0 {flowcount}"
	exit 1
fi

server=node1:9000
npm=../bin/netperfmeter-bsd64
outdir=results/$(basename ${0%.*})_$(uname -n | awk 'BEGIN { FS = "." } ; {print $2}')

# Duration of throughput tests (in seconds)
runtime=120

# Outgoing rate. Set to 'const0' to send as much as possible.
# Packet size = 1452 bytes (MTU of 1500 - IP/UDP header)
outrate=const0
outlen=const1452

# No incoming flow (half-duplex). set both rate and size 
# to 'const0' to disable
inrate=const0
inlen=const0

# Tx buffer should be set as high as allowed by kernel.
# Rx buffer should be half the Tx buffer.
rcvbuf=rcvbuf=7000000
sndbuf=sndbuf=14000000

flowspec=$outrate:$outlen:$inrate:$inlen:$rcvbuf:$sndbuf

# Create output directory if necessary
[ ! -d $outdir ] && mkdir -p $outdir 2>/dev/null

echo "*** Running TCP test (flows=$1) for $runtime seconds"
sudo sysctl net.inet.sctp.cmt_on_off=0
pre=tcp$1-bsd
$npm $server $(yes " -tcp $flowspec" | head -n$1) -runtime=$runtime > ${outdir}/${pre}.tx.txt

